# -*- coding: utf-8 -*-
"""
Created on Tue Jul 27 19:05:37 2021

@author: bpaqueletwuetz
"""
import numpy as np
import matplotlib
import matplotlib.pyplot as plt
from scipy.optimize import curve_fit
import os
abspath = os.path.abspath(__file__)
dname = os.path.dirname(abspath)
os.chdir(dname)
from os import listdir
from os.path import isfile, join
onlyfiles = [f for f in listdir(dname) if isfile(join(dname, f)) and f.endswith(".txt")]
from scipy.stats import linregress


#%% set paramenters for all figures           
plt.rcParams['figure.dpi'] = 300 #Note: this is helpuful for high dpi displays such as 4k display on Windows
plt.rcParams['figure.autolayout'] = True
plt.rcParams['lines.markersize'] = 1
plt.rcParams['lines.linewidth'] = 1
plt.rcParams['font.size'] = 8
plt.rcParams['font.sans-serif'] = "Arial"
plt.rcParams['font.family'] = "sans-serif"
plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'
plt.rcParams['axes.facecolor'] = 'white'
plt.rcParams['pdf.fonttype'] = 42
plt.rcParams['ps.fonttype'] = 42
plt.rcParams['axes.linewidth'] = 1
plt.rcParams['axes.edgecolor'] = 'black'
plt.rcParams['xtick.color'] = 'black'
plt.rcParams['ytick.color'] = 'black'

plt.rcParams['mathtext.rm'] = 'Arial'
plt.rcParams['mathtext.it'] = 'Arial'
plt.rcParams['mathtext.default'] = 'it'

plt.rcParams['lines.linewidth'] = 1
plt.rcParams["legend.numpoints"] = 1
plt.rcParams["legend.frameon"] = False
#mpl.rcParams['figure.figsize'] = (4, 3)
plt.rcParams['font.size'] = 8
plt.rcParams['font.family'] = 'Arial'

# #Setting finally the Text characters to regular instead of italics.
plt.rcParams['mathtext.rm'] = 'Arial'                 #'custom''Arial' #custom make mu italic, Arial straight
plt.rcParams['mathtext.it'] = 'Arial: italic'         #make latex italics unless use \mathrm{}
plt.rcParams['mathtext.default'] = 'it'#'regular'
plt.rcParams['xtick.major.width'] = 0.5
plt.rcParams['ytick.major.width'] = 0.5
# plt.rcParams["errorbar.capsize"]= 3
plt.rcParams['savefig.bbox'] = 'tight' #to avoid clipping mask cropping the axis label
#%%


import scipy.constants
# from qtt.algorithms.tunneling import fit_pol_all, polmod_all_2slopes, plot_polarization_fit


el_charge = 1.602*10**(-19)                  # elementary charge
K_Boltzmann = 1.38064852*10**(-23)           # Boltzmann constant in eV
Bohr = 9.274009994*10**(-24)                 # Bohr magneton in eV
Planck = 1.054571800*10**(-34)               # Planck constant in eV
gv = 2 #valley degeneracy
gs = 2 # spin degeneracy
# dens = np.array(np.concatenate(([np.linspace(1e10,1e11,50),np.linspace(1e11,1e12,50)])))*10000
dielectric = 8.854*10**-12
permittivity = 11.7
z0 = 27.6e-9 # distance of sheet density, done with TEM
mid_gap = 5e-1*el_charge #from Monroe 1992

# QT710

stop_fit = [10] #because the mob-dens curves did not have a filter we had to manuyally cut the data, this is how much data points we cut
#sample 4,5,6  not fittable in 3 impurity model
#noTDD
data = np.genfromtxt("MobDens_Sample_6.0.txt", dtype=np.float64,
                      delimiter=" ")
dens = np.array(data[1:-1,2])
y =  np.array(data[1:-1:,4])
# dens,y = zip(*sorted(zip(dens, y)))
# dens = np.array(dens) 
# y = np.array(y)

# pertubation = (el_charge**2/(dielectric*permittivity))*0.5*dens #electrick field in eV/m,
# # pertubation = 4*10**4.*el_charge/(10**-2); #electrick field in eV/cm, factor 10^-2 to normalize to meters
# l_debye = (1/(el_charge**2*dens/(2*dielectric*permittivity*mid_gap)))
# kf = np.array(np.sqrt(4*np.pi*dens/(gv*gs)))
# kl = 1./kf



#%% mob_dens plot
cms = 1/2.54
fig = plt.figure(12,figsize=(4.3*cms,4.7*cms), dpi = 600,constrained_layout = True)
ax = fig.add_subplot(111)
ax.tick_params(axis='both', direction='in')
plt.plot(dens/10**11, y/10**5, '-', color='black', alpha=1)


# # plt.plot(dens/10000, y_line, '-', color='red', alpha=1)
plt.ylim([0, 2.5])
plt.xlim([0, 7])
# # plt.legend(loc= 'upper left',fontsize=6)
plt.xlabel("$n$ ($10^{11}$ cm$^{-2}$)")
plt.ylabel("$\mu$ ($10^{5}$ cm$^2$/Vs)")
# # plt.ticklabel_format(axis="y", style="sci", scilimits=(0,0))
plt.xticks([000,2,4,6])
# # plt.ticklabel_format(axis="x", style="sci", scilimits=(0,0))

# plt.savefig(fname = 'mob_dens.pdf', dpi=None,
#         orientation='portrait', papertype=None, format=None,
#         transparent=True, bbox_inches='tight', pad_inches=0.1,
#         frameon=None, metadata=None)

#%% cond_dens plot
cond = (y*dens*el_charge)/(el_charge**2/(Planck*2*np.pi))

def perc(dens,n_p,A):
    return 1.31*np.log10(dens-n_p)+A
def perc_plot(dens,n_p,A):
    return A*abs(dens-n_p)**1.31
popt,covm = curve_fit(perc_plot, dens[0:40],cond[0:40],[9e10,1e-12])
x_line = np.arange(min(dens), max(dens), 4e9)
# calculate the output for the range
y_line = perc_plot(x_line, popt[0], popt[1])
fig = plt.figure(12,figsize=(4.3*cms,4.7*cms), dpi = 600,constrained_layout = True)
ax = fig.add_subplot(111)
ax.tick_params(axis='both', direction='in')
plt.scatter(dens/10**11, cond,s=1, color='black', alpha=1,label='data')
plt.plot(x_line/10**11,y_line, '-', color='red', alpha=1,label='fit')


# # plt.plot(dens/10000, y_line, '-', color='red', alpha=1)
plt.ylim([5, 100])
plt.xlim([0.7, 2.5])
# # plt.legend(loc= 'upper left',fontsize=6)
plt.xlabel("$n$ ($10^{11}$ cm$^{-2}$)")
plt.ylabel("$\sigma_{xx}$ (e$^2$/h)")
# # plt.ticklabel_format(axis="y", style="sci", scilimits=(0,0))
plt.xticks([1,2])
plt.minorticks_on()
# plt.minorticks_params(labelbottom=False, bottom = True, direction = 'in', width =1, top = False, right =0, length=5)
# # plt.ticklabel_format(axis="x", style="sci", scilimits=(0,0))
ax.set_yscale('log')
# plt.savefig(fname = 'cond_dens.pdf', dpi=None,
#         orientation='portrait', papertype=None, format=None,
#         transparent=True, bbox_inches='tight', pad_inches=0.1,
#         frameon=None, metadata=None)